@@ -12,14 +12,11 @@ Geo::Coder::Many::Ovi - Ovi plugin Geo::Coder::Many
 
 =head1 VERSION
 
-Version 0.02
+Version 0.01
 
 =cut
 
-our $VERSION = '0.02';
-
-# Requires Geo::Coder::Ovi 0.01 or above
-sub _MIN_MODULE_VERSION { return '0.01'; }
+our $VERSION = '0.01';
 
 =head1 SYNOPSIS
 
@@ -127,7 +124,7 @@ Returns the name of the geocoder type - used by Geo::Coder::Many
 
 =cut
 
-sub get_name { my $self = shift; return 'ovi ' . $self->{GeoCoder}->VERSION; }
+sub get_name { return 'ovi'; }
 
 1; 
 
