@@ -108,7 +108,7 @@ sub geocode {
 }
 
 # return number between 0 and 1
-sub _deteremine_precision {
+sub _determine_precision {
     my $self = shift;
     my $raw  = shift;
 
